@@ -37,7 +37,7 @@ class PluginWriter:
 
         for key, value in d.items():
             if isinstance(value, dict):
-                text += f"-{key} \"{json.dumps()}\""
+                text += f"-{key} \"{json.dumps(value)}\""
             elif isinstance(value, str):
                 text += f"-{key} \"{value}\""
             else:
